============
Installation
============

At the command line::

    $ pip install etcd3-gateway

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv etcd3-gateway
    $ pip install etcd3-gateway
